/*
 * Copyright (C) 2004-2005 Andre Noll <maan@systemlinux.org>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */

/*
 * Simple database tool implementation for paraslash. Feel free to modify.
 */

#include "server.h"
static int com_dopey(int, int, char **);
extern struct gengetopt_args_info conf;
extern struct misc_meta_data *mmd;


static struct command cmds[] = {
	{
		.name = "dopey",
		.handler = com_dopey,
		.perms = 0,
		.description = "about the dopey database tool",
		.usage = "dopey",
		.help =
                "It's so dumb. It hurts. Don't use it; switch to     \n"
                "the mysql database tool instead. OTOH: You typed    \n"
                "\"help dopey\", so if you serious about that and    \n"
                "you really intend to help the dopey database tool,  \n"
                "look at its source code, dopey.c, and modify to     \n"
                "make it something useful.                           \n"
	}, {
		.name = NULL,
	}
};

static int com_dopey(int fd, int argc, char *argv[])
{
	send_va_buffer(fd, "please do not execute me. I'm too sick to do "
		"anything for you. Switch me off. Now!\n");
	return 1;
}

/* this is a simple implementation which selects random
 * mp3 files by using find and $RANDOM to randomize 
 */
static char **dopey_get_song_list(int num)
{
	char **list = para_malloc((num + 1)
		* sizeof(char *));
	char *find_cmd = make_message("(find %s  -type f -name \"*.mp3\" -print"
	"| while read a ; do echo \"$RANDOM:$a\"; done "
	"| sort -n | cut -f 2-99 -d':') 2>/dev/null", conf.dopey_dir_arg);
	int i;
	FILE* pipe;
	char buf[8192];
	
	clog(DEBUG, "%s: exec %s\n", __func__, find_cmd);
	pipe = popen(find_cmd, "r");
	free(find_cmd);
	if (!pipe)
		goto err_out;
	for (i = 0; i < num && fgets(buf, 8191, pipe); i++) {
		chop(buf);
		list[i] = strdup(buf);
	}
	list[i] = NULL;
	pclose(pipe);
	if (i)
		return list;
	free(list);
	return NULL;
err_out:
	for (i = 0; list[i]; i++)
		free(list[i]);
	free(list);
	return NULL;
}
static void dopey_shutdown(void)
{
	clog(DEBUG, "%s: Thanks for using another dbtool.\n", 
		__func__);
}

#define DBINFO "dbinfo1:database info? You're kidding. I'm dopey!\ndbinfo2:\ndbinfo3:\n"

static void dopey_update_song(char *name)
{
	sprintf(mmd->dbinfo, DBINFO);
	clog(DEBUG, "%s: update? Don't make me laugh.\n", __func__);
}

int dopey_dbtool_init(struct dbtool *db)
{
	clog(INFO, "%s: registering dopey handlers\n", __func__);
	sprintf(mmd->dbinfo, DBINFO);

	db->cmd_list = cmds;
	db->get_song_list = dopey_get_song_list;
	db->update_song = dopey_update_song;
	db->shutdown = dopey_shutdown;
	return 1;
}
